==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Añadir archivos</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="44"/>
        <source>Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="47"/>
        <location filename="../qmmpfiledialog.ui" line="60"/>
        <location filename="../qmmpfiledialog.ui" line="79"/>
        <location filename="../qmmpfiledialog.ui" line="104"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="57"/>
        <source>List view</source>
        <translation>Vista de lista</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="76"/>
        <source>Detailed view</source>
        <translation>Vista detallada</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="101"/>
        <source>Close dialog on add</source>
        <translation>Cerrar diálogo al añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="184"/>
        <source>File name:</source>
        <translation>Nombre del archivo:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="207"/>
        <source>Files of type:</source>
        <translation>Archivos de tipo:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="233"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="68"/>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>Qmmp File Dialog</source>
        <translation>Diálogo de archivos para Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="77"/>
        <source>About Qmmp File Dialog</source>
        <translation>Acerca del diálogo de archivos para Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="82"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Parte del código se ha copiado de la librería Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
        <source>Directories</source>
        <translation>Directorios</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 ya existe.
¿Quiere reemplazarlo?</translation>
    </message>
</context>
</TS>

==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Añadir archivos</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Vista de lista</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Vista detallada</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Cerrar diálogo al añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Nombre del archivo:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Archivos de tipo:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="114"/>
        <location filename="../qmmpfiledialog.cpp" line="124"/>
        <source>Qmmp File Dialog</source>
        <translation>Diálogo de archivos para Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="123"/>
        <source>About Qmmp File Dialog</source>
        <translation>Acerca del diálogo de archivos para Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="125"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="128"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Parte del código se ha copiado de la librería Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="254"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="267"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="281"/>
        <source>Directories</source>
        <translation>Directorios</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="450"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 ya existe.
¿Quiere reemplazarlo?</translation>
    </message>
</context>
</TS>
